<!--
SPDX-FileCopyrightText: 2021 Ian2020, et. al. <https://github.com/Ian2020>

SPDX-License-Identifier: CC-BY-SA-4.0

Keep your accounts offline

For full copyright information see the AUTHORS file at the top-level
directory of this distribution or at
[AUTHORS](https://github.com/Ian2020/offlinebooks/AUTHORS.md)

This work is licensed under the Creative Commons Attribution 4.0 International
License. You should have received a copy of the license along with this work.
If not, visit http://creativecommons.org/licenses/by/4.0/ or send a letter to
Creative Commons, PO Box 1866, Mountain View, CA 94042, USA.
-->

# Benevolent Dictator

The Benevolent Dictator holds ultimate decision-making power, until the group is
ready for a more inclusive structure.

* **Values** Servant leadership, singular vision, voluntarism
* **Membership** Participation is open to anyone who wants to join, but the
  Benevolent Dictator can remove participants at will.
* **Autocracy** The Benevolent Dictator has authority and can change the group's
  governance as necessary.
  * **Delegation** The Benevolent Dictator can invite participants to help with
    managing the group.
  * **Expiration** When the group is sufficiently mature, the Benevolent
    Dictator will establish a more inclusive structure.
  * **Executive** The Benevolent Dictator is responsible for implementing—or
    delegating implementation of—policies and other decisions.
  * **Lobbying** If participants are not happy with the Benevolent Dictator's
    leadership, they may voice their concerns or leave the group.

[![CommunityRule derived](https://communityrule.info/assets/CommunityRule-derived-000000.svg)](https://communityrule.info)
[Creative Commons BY-SA](https://creativecommons.org/licenses/by-sa/4.0/)
